@@ -7,8 +7,8 @@
 
 """CLI module."""
 
-from distutils.sysconfig import get_python_lib
 from functools import update_wrapper
+from pathlib import Path
 
 import click
 
@@ -22,6 +22,12 @@ from .env import (
 from .services import services_down, services_up
 
 
+def _get_module_path():
+    """Gets the path in which the module is installed."""
+    parent_path = Path(__file__).parent
+    return str(parent_path)
+
+
 def env_output(env_set_command):
     """Decorate command to print exportable environment settings."""
     if env_set_command not in ["export", "unset"]:
@@ -125,7 +131,7 @@ class ServicesCtx(object):
     "--filepath",
     "-f",
     required=False,
-    default=f"{get_python_lib()}/docker_services_cli/docker-services.yml",
+    default=f"{_get_module_path()}/docker-services.yml",
     type=click.Path(exists=True),
     help="Path to a docker compose file with the desired services definition.",
 )
@@ -160,8 +166,8 @@ def cli(ctx, filepath, verbose):
 def up(services_ctx, services, no_wait, retries):
     r"""Boots up the required services.
 
-    Example: \n
-    \t $ docker-services-cli up --db postgresql11
+    Example:
+        $ docker-services-cli up --db postgresql11
 
     Note: All services will be boot up if no service is specified.
     """
@@ -189,6 +195,6 @@ def up(services_ctx, services, no_wait, retries):
 @env_output(env_set_command="unset")
 @click.pass_obj
 def down(services_ctx):
-    """Boots down the required services."""
+    """Shuts down the required services."""
     services_down(filepath=services_ctx.filepath)
     click.secho("Services down!", fg="green")
